@@ -10,7 +10,7 @@ use Carp;
 use File::Spec;
 
 my @optionals_dir = qw{ xt author optionals };
-my @hide = qw{ LWP::Protocol::https SOAP::Lite Time::HiRes };
+my @hide = qw{ Time::HiRes };
 
 {
     my $done;
@@ -118,6 +118,17 @@ sub ACTION_authortest {
     return;
 }
 
+sub ACTION_test {
+    my ( $self, @args ) = @_;
+
+    -e 'META.json'
+	or $self->depends_on( 'distmeta' );
+
+    $self->depends_on( 'build' );
+
+    return $self->SUPER::ACTION_test( @args );
+}
+
 1;
 
 __END__
@@ -180,7 +191,7 @@ C<authortest> action depends on it.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -188,7 +199,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 Thomas R. Wyant, III
+Copyright (C) 2009-2020 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
