@@ -53,6 +53,7 @@ sub requires {
 	'Carp'			=> 0,
 	'HTTP::Request::Common'	=> 0,
 	'JSON'			=> 0,
+	'LWP::Protocol::https'	=> 0,
 	'LWP::UserAgent'	=> 0,
 	'Scalar::Util'		=> 1.10,
 	'strict'		=> 0,
@@ -170,7 +171,7 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -178,7 +179,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2019 Thomas R. Wyant, III
+Copyright (C) 2010-2020 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
